### Name: logconSmoothed
### Title: Compute convolution of log-concave density estimator with a
###   normal kernel
### Aliases: logconSmoothed
### Keywords: htest nonparametric

### ** Examples


## ===================================================
## Reproduce Fig. 2 in Duembgen & Rufibach (2009)
## ===================================================

## Set parameters
data(reliability)
x0 <- sort(reliability)
n0 <- length(x0)
x <- unique(x0)
w <- as.vector(table(x0))
w <- w / n0
n <- length(x)
res <- activeSetLogCon(x, w, print = TRUE)
phi <- res$phi
f <- exp(phi)

## compute normal density
mu <- mean(x0)
sig <- sd(x0)

## compute smoothed log-concave density estimator
f.smoothed <- logconSmoothed(x = x, w = w, phi, gam = NULL, sig = sig)
xs <- f.smoothed$xs

## compute kernel density
h <- sig / sqrt(n0)
f.kernel <- rep(NA, length(xs))
for (i in 1:length(xs)){
    xi <- xs[i]
    f.kernel[i] <- mean(dnorm(xi, mean = x0, sd = h))
}

## compute normal density
f.normal <- dnorm(xs, mean = mu, sd = sig)

## ===================================================
## Plot resulting densities, i.e. reproduce Fig. 2
## in Duembgen and Rufibach (2009)
## ===================================================
plot(0, 0, type = 'n', xlim = range(xs), ylim = c(0, 6.5 * 10^-3))
rug(x)
lines(x, f, col = 2)
lines(xs, f.normal, col = 3)
lines(xs, f.kernel, col = 4)
lines(xs, f.smoothed$f.smoothed, lwd = 3, col = 5)
legend("topleft", c("log-concave", "normal", "kernel", 
    "log-concave smoothed"), lty = 1, col = 2:5, bty = "n")

## ===================================================
## Plot log-densities
## ===================================================
plot(0, 0, type = 'n', xlim = range(xs), ylim = c(-20, -5))
legend("bottomright", c("log-concave", "normal", "kernel", 
    "log-concave smoothed"), lty = 1, col = 2:5, bty = "n")
rug(x)
lines(x, phi, col = 2)
lines(xs, log(f.normal), col = 3)
lines(xs, log(f.kernel), col = 4)
lines(xs, log(f.smoothed$f.smoothed), lwd = 3, col = 5)



